Lemonade Server

{{SERVER_MODELS_JS}} {{PLATFORM_JS}}
View Logs
Use Lemonade with your favorite app
Open WebUI Continue Gaia AnythingLLM AI Dev Gallery LM-Eval Lemonade Arcade AI Toolkit
Temperature: Controls randomness in responses (0 = deterministic, 2 = very random)
Top K: Limits token selection to top K most likely tokens
Top P: Nucleus sampling - considers tokens with cumulative probability up to P
Repeat Penalty: Penalty for repeating tokens (1 = no penalty, >1 = less repetition)
Enable Thinking:
Determines whether hybrid reasoning models, such as Qwen3, will use thinking.
Model Name ⓘ
user.
Checkpoint ⓘ
Recipe ⓘ
More info
mmproj file ⓘ
Reasoning ⓘ Vision ⓘ Embedding ⓘ Reranking ⓘ

## Clean Up Incompatible Models

The following RyzenAI models are incompatible with RyzenAI 1.6 and can be safely deleted:

After deleting, you can re-download compatible Ryzen AI 1.6 models from the OGA NPU and OGA Hybrid tabs.

Total space to free: